### Сбор данных с сайта объявлений об аренде и продаже недвижимости Циан

Cianparser - это библиотека Python 3 для парсинга сайта  [Циан](http://cian.ru).
С его помощью можно получить достаточно подробные и структурированные данные по краткосрочной и долгосрочной аренде, продаже квартир, домов, танхаусов итд.

### Установка
```bash
pip install cianparser
```

### Использование
```python
>>> import cianparser
    
>>> data = cianparser.parse(
        deal_type="rent_long",
        accommodation_type="flat",
        location="Москва",
        rooms=(2, 3),
        start_page=1,
        end_page=2,
        is_saving_csv=True,
        is_latin=False,
        is_express=False,
    )

>>> print(data[0])
```

```
                  Collecting information from pages..

The absolute path to the file: 
 /Users/macbook/some_project/cian_parsing_result_rent_long_1_2_moskva_2023-02-04 06:58:21.765479.csv 

The page from which the collection of information begins: 
 https://cian.ru/cat.php?engine_version=2&p=1&region=1&offer_type=flat&deal_type=rent&room2=1&room3=1&with_neighbors=0&type=4 

Setting [=>=>=>=>=>=>=>=>=>=>=>=>=>=>=>=>=>=>=>=>=>=>=>=>=>=>=>=>] 100%
1 page: [=>=>=>=>=>=>=>=>=>=>=>=>=>=>=>=>=>=>=>=>=>=>=>=>=>=>=>=>] 100%
2 page: [=>=>=>=>=>=>=>=>=>=>=>=>=>=>=>=>=>=>=>=>=>=>=>=>=>=>=>=>] 100%

{  'accommodation_type': 'flat',
   'deal_type': 'rent',
   'city': 'Москва',
   'district': 'Замоскворечье',
   'underground': 'Новокузнецкая',
   'street': 'Космодамианская набережная',
   'floor': 5,
   'floors_count': 12,
   'total_meters': 85.0,
   'living_meters': 55.0,
   'kitchen_meters': 11.0,
   'rooms_count': 3,
   'year_of_construction': '1954',
   'price_per_month': 93000,
   'commissions': 50,
   'author': 'Apple Real Estate',
   'link': 'https://www.cian.ru/rent/flat/282487326/',
}
```

### Конфигурация
Функция __*parse*__ имеет следующий аргументы:
* __deal_type__ - тип объявления, к примеру, долгосрочная, краткосрочная аренда, продажа _("rent_long", "rent_short", "sale")_
* __accommodation_type__ - вид жилья, к примеру, квартира, комната, дом, часть дома, таунхаус _("flat", "room", "house", "house-part", "townhouse")_
* __location__ - локация объявления, к примеру, Казань (для просмотра доступных мест используйте _cianparser.list_cities())_
* __rooms__ - количество комнат, к примеру, _1, (1,3, "studio"), "studio, "all"_; по умолчанию любое _("all")_
* __start_page__ - страница, с которого начинается сбор данных, по умолчанию, _1_
* __end_page__ - страница, с которого заканчивается сбор данных, по умолчанию, _10_
* __is_saving_csv__ - необходимо ли сохранять данные (в реальном времени в процессе сбора данных) или нет, по умолчанию _False_
* __is_latin__ - необходимо ли преобразовывать встрещающиеся слова из кириллицы в латиницу, по умолчанию _False_
* __is_express__ - необходимо ли ускорить (___в 5-10 раз___) сбор данных (__но без двух полей__, см примечание), по умолчанию _False_

#### <ins> В настоящее время доступен только функционал продажи (sale) и долгосрочной аренды (rent_long) квартир (flat) и студий.

### Признаки, получаемые в ходе сбора данных с предложений по долгосрочной аренде недвижимости
* __district__ - район
* __underground__ - метро
* __street__ - улица
* __floor__ - этаж
* __floors_count__ - количество этажей
* __total_meters__ - общая площадь
* __living_meters__ - жилая площади
* __kitchen_meters__ - площадь кухни
* __rooms_count__ - количество комнат
* __year_construction__ - год постройки здания
* __price_per_month__ - стоимость аренды в месяц
* __commissions__ - комиссия, взымаемая в ходе заселения
* __author__ - автор объявления
* __link__ - ссылка на данное объявление

### Признаки, получаемые в ходе сбора данных с предложений по продаже недвижимости

Признаки __аналогичны__ вышеописанным, кроме отсутствия полей __price_per_month__ и __commissions__.

При этом появляются новые:
* __price__ - стоимость недвижимости
* __residential_complex__ - название жилого комплекса

### Сохранение данных
Имеется возможность сохранения собираемых данных в режиме реального времени. Для этого необходимо подставить в аргументе 
__is_saving_csv__ значение ___True___.

Пример получаемого файла:

```bash
cian_parsing_result_rent_long_1_2_moskva_2023-02-04 06:58:21.765479.csv
```

| author | link | city | deal_type | accommodation_type | floor | floors_count | rooms_count | total_meters | price_per_month | commissions | year_of_construction | living_meters | kitchen_meters | district | street | underground
| --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | ---
| Intermark Real Estate | https://www.cian.ru/rent/flat/278903117/ | Москва | rent | flat | 4 | 6 | 3 | 50.0 | 180000 | 0 | 1911 | 32.0 | 8.0 | Пресненский | Малый Предтеченский переулок | Краснопресненская
| Capital Mars | https://www.cian.ru/rent/flat/282506328/ | Москва | rent | flat | 5 | 9 | 2 | 89.0 | 180000 | 0 | 2006 | 53.0 | 15.0 | Хамовники | 3-я Фрунзенская | Спортивная
| MERSI | https://www.cian.ru/rent/flat/281562376/ | Москва | rent | flat | 8 | 16 | 2 | 80.0 | 200000 | 0 | 2012 | -1 | -1 | Замоскворечье | Мытная | Октябрьская


### Некоторые сведения
1. В процессе парсинга имеется возможность задать преобразывание любой встрещающейся __кириллицы__ в __латиницу__. 
Для этого необходимо подставить в аргументе __is_latin__ значение ___True___.

2. В некоторых объявлениях отсутсвуют данные по некоторым признакам (_год постройки, жилые кв метры, кв метры кухни итп_).
В этом случае проставляется значение ___-1___ либо ___пустая строка___ для числового и строкового типа поля соответственно.


### Примечание
1. Для отсутствия блокировки по __IP__ в данном проекте задана пауза (___в размере 5 секунд___) после сбора информации с
каждой отдельной взятой страницы.

2. Имеется флаг __is_express__, при помощи которого можно существенно (___в 5-10 раз___) ускорить сбор данных благодаря отсутствию необходимости 
заходить на каждую страницу с предложением. 
Однако в таком случае __не будут__ собираться данные о ___площади кухни___ и ___годе постройки здания___.

3. Данный парсер не будет работать в таком инструменте как [Google Colaboratory](https://colab.research.google.com/). 
См. [подробности](https://github.com/lenarsaitov/cianparser/issues/1)
